package com.zhyc.module.base.service;

import java.util.List;
import com.zhyc.module.base.domain.SheepPedigree;

/**
 * VIEWService接口
 * 
 * @author ruoyi
 * @date 2026-02-04
 */
public interface ISheepPedigreeService 
{
    /**
     * 查询VIEW
     * 
     * @param id VIEW主键
     * @return VIEW
     */
    public SheepPedigree selectSheepPedigreeById(Long id);

    /**
     * 查询VIEW列表
     * 
     * @param sheepPedigree VIEW
     * @return VIEW集合
     */
    public List<SheepPedigree> selectSheepPedigreeList(SheepPedigree sheepPedigree);

    /**
     * 新增VIEW
     * 
     * @param sheepPedigree VIEW
     * @return 结果
     */
    public int insertSheepPedigree(SheepPedigree sheepPedigree);

    /**
     * 修改VIEW
     * 
     * @param sheepPedigree VIEW
     * @return 结果
     */
    public int updateSheepPedigree(SheepPedigree sheepPedigree);

    /**
     * 批量删除VIEW
     * 
     * @param ids 需要删除的VIEW主键集合
     * @return 结果
     */
    public int deleteSheepPedigreeByIds(Long[] ids);

    /**
     * 删除VIEW信息
     * 
     * @param id VIEW主键
     * @return 结果
     */
    public int deleteSheepPedigreeById(Long id);

    public String getBreedNameById(Long id);
}
